@@ -42,8 +42,16 @@ class SybilItem(pytest.Item):
     def request_fixtures(self, names):
         # pytest fixtures dance:
         fm = self.session._fixturemanager
-        names_closure, arg2fixturedefs = fm.getfixtureclosure(names, self)
-        fixtureinfo = FuncFixtureInfo(names, names_closure, arg2fixturedefs)
+        closure = fm.getfixtureclosure(names, self)
+        try:
+            initialnames, names_closure, arg2fixturedefs = closure
+        except ValueError:
+            # pytest < 3.7
+            names_closure, arg2fixturedefs = closure
+            fixtureinfo = FuncFixtureInfo(names, names_closure, arg2fixturedefs)
+        else:
+            # pyest >= 3.7
+            fixtureinfo = FuncFixtureInfo(names, initialnames, names_closure, arg2fixturedefs)
         self._fixtureinfo = fixtureinfo
         self.funcargs = {}
         self._request = fixtures.FixtureRequest(self)
